/********************************************************************************
** Form generated from reading UI file 'general.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERAL_H
#define UI_GENERAL_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_General
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox3;
    QVBoxLayout *vboxLayout1;
    QHBoxLayout *hboxLayout;
    QLabel *textLabel3;
    QSlider *kcfg_StartHitPoints0;
    QSpinBox *spinBox_2;
    QHBoxLayout *hboxLayout1;
    QLabel *textLabel4;
    QSlider *kcfg_StartHitPoints1;
    QSpinBox *spinBox_3;
    QGroupBox *groupBox4;
    QHBoxLayout *hboxLayout2;
    QLabel *textLabel5;
    QSlider *kcfg_RefreshTime;
    QSpinBox *spinBox;
    QHBoxLayout *hboxLayout3;
    QGroupBox *groupBox1;
    QVBoxLayout *vboxLayout2;
    QHBoxLayout *hboxLayout4;
    QCheckBox *kcfg_Player0IsAi;
    QSpacerItem *spacerItem;
    QHBoxLayout *hboxLayout5;
    QLabel *textLabel1;
    QComboBox *kcfg_AiDifficulty0;
    QGroupBox *groupBox2;
    QVBoxLayout *vboxLayout3;
    QHBoxLayout *hboxLayout6;
    QCheckBox *kcfg_Player1IsAi;
    QSpacerItem *spacerItem1;
    QHBoxLayout *hboxLayout7;
    QLabel *textLabel2;
    QComboBox *kcfg_AiDifficulty1;
    QSpacerItem *spacerItem2;

    void setupUi(QWidget *General)
    {
        if (General->objectName().isEmpty())
            General->setObjectName("General");
        General->resize(398, 441);
        vboxLayout = new QVBoxLayout(General);
        vboxLayout->setObjectName("vboxLayout");
        groupBox3 = new QGroupBox(General);
        groupBox3->setObjectName("groupBox3");
        vboxLayout1 = new QVBoxLayout(groupBox3);
        vboxLayout1->setObjectName("vboxLayout1");
        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MACOS
        hboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout->setObjectName("hboxLayout");
        textLabel3 = new QLabel(groupBox3);
        textLabel3->setObjectName("textLabel3");

        hboxLayout->addWidget(textLabel3);

        kcfg_StartHitPoints0 = new QSlider(groupBox3);
        kcfg_StartHitPoints0->setObjectName("kcfg_StartHitPoints0");
        kcfg_StartHitPoints0->setMinimum(1);
        kcfg_StartHitPoints0->setValue(99);
        kcfg_StartHitPoints0->setSliderPosition(99);
        kcfg_StartHitPoints0->setOrientation(Qt::Horizontal);

        hboxLayout->addWidget(kcfg_StartHitPoints0);

        spinBox_2 = new QSpinBox(groupBox3);
        spinBox_2->setObjectName("spinBox_2");
        spinBox_2->setValue(99);

        hboxLayout->addWidget(spinBox_2);


        vboxLayout1->addLayout(hboxLayout);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setContentsMargins(0, 0, 0, 0);
        hboxLayout1->setObjectName("hboxLayout1");
        textLabel4 = new QLabel(groupBox3);
        textLabel4->setObjectName("textLabel4");

        hboxLayout1->addWidget(textLabel4);

        kcfg_StartHitPoints1 = new QSlider(groupBox3);
        kcfg_StartHitPoints1->setObjectName("kcfg_StartHitPoints1");
        kcfg_StartHitPoints1->setMinimum(1);
        kcfg_StartHitPoints1->setValue(99);
        kcfg_StartHitPoints1->setSliderPosition(99);
        kcfg_StartHitPoints1->setOrientation(Qt::Horizontal);

        hboxLayout1->addWidget(kcfg_StartHitPoints1);

        spinBox_3 = new QSpinBox(groupBox3);
        spinBox_3->setObjectName("spinBox_3");
        spinBox_3->setValue(99);

        hboxLayout1->addWidget(spinBox_3);


        vboxLayout1->addLayout(hboxLayout1);


        vboxLayout->addWidget(groupBox3);

        groupBox4 = new QGroupBox(General);
        groupBox4->setObjectName("groupBox4");
        hboxLayout2 = new QHBoxLayout(groupBox4);
        hboxLayout2->setObjectName("hboxLayout2");
        textLabel5 = new QLabel(groupBox4);
        textLabel5->setObjectName("textLabel5");

        hboxLayout2->addWidget(textLabel5);

        kcfg_RefreshTime = new QSlider(groupBox4);
        kcfg_RefreshTime->setObjectName("kcfg_RefreshTime");
        kcfg_RefreshTime->setMinimum(10);
        kcfg_RefreshTime->setMaximum(100);
        kcfg_RefreshTime->setValue(33);
        kcfg_RefreshTime->setOrientation(Qt::Horizontal);

        hboxLayout2->addWidget(kcfg_RefreshTime);

        spinBox = new QSpinBox(groupBox4);
        spinBox->setObjectName("spinBox");
        spinBox->setMaximum(100);
        spinBox->setMinimum(10);
        spinBox->setValue(33);

        hboxLayout2->addWidget(spinBox);


        vboxLayout->addWidget(groupBox4);

        hboxLayout3 = new QHBoxLayout();
        hboxLayout3->setContentsMargins(0, 0, 0, 0);
        hboxLayout3->setObjectName("hboxLayout3");
        groupBox1 = new QGroupBox(General);
        groupBox1->setObjectName("groupBox1");
        vboxLayout2 = new QVBoxLayout(groupBox1);
        vboxLayout2->setObjectName("vboxLayout2");
        hboxLayout4 = new QHBoxLayout();
#ifndef UI_Q_OS_MACOS
        hboxLayout4->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout4->setObjectName("hboxLayout4");
        kcfg_Player0IsAi = new QCheckBox(groupBox1);
        kcfg_Player0IsAi->setObjectName("kcfg_Player0IsAi");

        hboxLayout4->addWidget(kcfg_Player0IsAi);

        spacerItem = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout4->addItem(spacerItem);


        vboxLayout2->addLayout(hboxLayout4);

        hboxLayout5 = new QHBoxLayout();
        hboxLayout5->setContentsMargins(0, 0, 0, 0);
        hboxLayout5->setObjectName("hboxLayout5");
        textLabel1 = new QLabel(groupBox1);
        textLabel1->setObjectName("textLabel1");
        textLabel1->setEnabled(false);

        hboxLayout5->addWidget(textLabel1);

        kcfg_AiDifficulty0 = new QComboBox(groupBox1);
        kcfg_AiDifficulty0->addItem(QString());
        kcfg_AiDifficulty0->addItem(QString());
        kcfg_AiDifficulty0->addItem(QString());
        kcfg_AiDifficulty0->addItem(QString());
        kcfg_AiDifficulty0->setObjectName("kcfg_AiDifficulty0");
        kcfg_AiDifficulty0->setEnabled(false);

        hboxLayout5->addWidget(kcfg_AiDifficulty0);


        vboxLayout2->addLayout(hboxLayout5);


        hboxLayout3->addWidget(groupBox1);

        groupBox2 = new QGroupBox(General);
        groupBox2->setObjectName("groupBox2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox2->sizePolicy().hasHeightForWidth());
        groupBox2->setSizePolicy(sizePolicy);
        vboxLayout3 = new QVBoxLayout(groupBox2);
        vboxLayout3->setObjectName("vboxLayout3");
        hboxLayout6 = new QHBoxLayout();
#ifndef UI_Q_OS_MACOS
        hboxLayout6->setContentsMargins(0, 0, 0, 0);
#endif
        hboxLayout6->setObjectName("hboxLayout6");
        kcfg_Player1IsAi = new QCheckBox(groupBox2);
        kcfg_Player1IsAi->setObjectName("kcfg_Player1IsAi");

        hboxLayout6->addWidget(kcfg_Player1IsAi);

        spacerItem1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout6->addItem(spacerItem1);


        vboxLayout3->addLayout(hboxLayout6);

        hboxLayout7 = new QHBoxLayout();
        hboxLayout7->setContentsMargins(0, 0, 0, 0);
        hboxLayout7->setObjectName("hboxLayout7");
        textLabel2 = new QLabel(groupBox2);
        textLabel2->setObjectName("textLabel2");
        textLabel2->setEnabled(false);

        hboxLayout7->addWidget(textLabel2);

        kcfg_AiDifficulty1 = new QComboBox(groupBox2);
        kcfg_AiDifficulty1->addItem(QString());
        kcfg_AiDifficulty1->addItem(QString());
        kcfg_AiDifficulty1->addItem(QString());
        kcfg_AiDifficulty1->addItem(QString());
        kcfg_AiDifficulty1->setObjectName("kcfg_AiDifficulty1");
        kcfg_AiDifficulty1->setEnabled(false);

        hboxLayout7->addWidget(kcfg_AiDifficulty1);


        vboxLayout3->addLayout(hboxLayout7);


        hboxLayout3->addWidget(groupBox2);


        vboxLayout->addLayout(hboxLayout3);

        spacerItem2 = new QSpacerItem(20, 91, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem2);


        retranslateUi(General);
        QObject::connect(kcfg_Player0IsAi, &QCheckBox::toggled, textLabel1, &QLabel::setEnabled);
        QObject::connect(kcfg_Player0IsAi, &QCheckBox::toggled, kcfg_AiDifficulty0, &QComboBox::setEnabled);
        QObject::connect(kcfg_Player1IsAi, &QCheckBox::toggled, textLabel2, &QLabel::setEnabled);
        QObject::connect(kcfg_Player1IsAi, &QCheckBox::toggled, kcfg_AiDifficulty1, &QComboBox::setEnabled);
        QObject::connect(kcfg_StartHitPoints0, &QSlider::valueChanged, spinBox_2, &QSpinBox::setValue);
        QObject::connect(spinBox_2, &QSpinBox::valueChanged, kcfg_StartHitPoints0, &QSlider::setValue);
        QObject::connect(kcfg_StartHitPoints1, &QSlider::valueChanged, spinBox_3, &QSpinBox::setValue);
        QObject::connect(spinBox_3, &QSpinBox::valueChanged, kcfg_StartHitPoints1, &QSlider::setValue);
        QObject::connect(kcfg_RefreshTime, &QSlider::valueChanged, spinBox, &QSpinBox::setValue);
        QObject::connect(spinBox, &QSpinBox::valueChanged, kcfg_RefreshTime, &QSlider::setValue);

        kcfg_AiDifficulty0->setCurrentIndex(1);
        kcfg_AiDifficulty1->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(General);
    } // setupUi

    void retranslateUi(QWidget *General)
    {
        groupBox3->setTitle(tr2i18n("Hit Points", nullptr));
        textLabel3->setText(tr2i18n("Red player:", nullptr));
        textLabel4->setText(tr2i18n("Blue player:", nullptr));
        groupBox4->setTitle(tr2i18n("Graphics", nullptr));
        textLabel5->setText(tr2i18n("Refresh time:", nullptr));
        groupBox1->setTitle(tr2i18n("Red Player", nullptr));
        kcfg_Player0IsAi->setText(tr2i18n("Player is AI", nullptr));
        textLabel1->setText(tr2i18n("Difficulty:", nullptr));
        kcfg_AiDifficulty0->setItemText(0, tr2i18n("Trainee", nullptr));
        kcfg_AiDifficulty0->setItemText(1, tr2i18n("Normal", nullptr));
        kcfg_AiDifficulty0->setItemText(2, tr2i18n("Hard", nullptr));
        kcfg_AiDifficulty0->setItemText(3, tr2i18n("Insane", nullptr));

        groupBox2->setTitle(tr2i18n("Blue Player", nullptr));
        kcfg_Player1IsAi->setText(tr2i18n("Player is AI", nullptr));
        textLabel2->setText(tr2i18n("Difficulty:", nullptr));
        kcfg_AiDifficulty1->setItemText(0, tr2i18n("Trainee", nullptr));
        kcfg_AiDifficulty1->setItemText(1, tr2i18n("Normal", nullptr));
        kcfg_AiDifficulty1->setItemText(2, tr2i18n("Hard", nullptr));
        kcfg_AiDifficulty1->setItemText(3, tr2i18n("Insane", nullptr));

        (void)General;
    } // retranslateUi

};

namespace Ui {
    class General: public Ui_General {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERAL_H

